# -*- rpm-spec -*-
%define origname samba

Name: samba
Version: 3.0.37
Release: alt4.M50P.1

# for pam modules
%add_findprov_lib_path /%_lib/security

%def_disable aw

# Do not use ccache while compiling Samba rpm by default
# you can enable ccaching by --enable ccache rpmbuild option
# and passing --define "__ccache_dir /path/to/cache" to override default setting
%def_disable ccache
%define	__ccache_dir $HOME/.ccache

# Adds python support
%def_enable python

# **** NOTE **** NOTE **** NOTE ****
# This spec file has special support for XScale build
# It differs in options we use to compile Samba with for AW subproject, mainly:
# - We do not build documentation
# - We do not use CUPS
# These decisions are enforced through '--enable aw' switch on armv5l architecture

# Enable xml and mysql passdb modules only for ALT Linux build
%if_enabled aw
%define version_string v5.3
%ifnarch armv5l
%def_enable cups
%def_enable gendoc
%else
%def_disable cups
%def_disable gendoc
%endif
%else
%define version_string ALT/%release
# Do not generate documentation out of Docbook sources by default
%def_enable gendoc
# Use CUPS by default
%def_enable cups
%endif

%define negotiate_kernel 02041803
# Current ALT kernel version, used for enabling 'negotiate'
# feature in smbmount, works only with kernels after %negotiate_kernel
%define current_kernel	02061800

Summary: Samba SMB/CIFS server
License: GNU GPL
Group: System/Servers
Url: http://www.samba.org/
Packager: Alexander Bokovoy <ab@altlinux.ru>
PreReq: chkconfig, coreutils, sed, grep, glibc-gconv-modules
PreReq: %name-common = %version-%release
Requires(post): shadow-utils
Obsoletes: samba3 < %version-%release
Provides: samba3

# Downloaded from ftp://ftp.samba.org/pub/samba/stable/samba-%version.tar.gz
# Signed by ftp://ftp.samba.org/pub/samba/stable/samba-%version.tar.asc
Source: samba-%version.tar
Source1: samba.log
Source2: mount.smb
Source3: samba.xinetd
Source4: swat_48.xpm.bz2
Source5: swat_32.xpm.bz2
Source6: swat_16.xpm.bz2
Source7: smb.init
Source8: winbind.init
Source15: using_samba.tar.bz2

# Config files for ALT Linux and ApplianceWare respectively
Source21: smb.conf
Source22: smb-aw.conf
Source23: system-auth-winbind
Source24: aw-system-auth-winbind
# Pam config for samba-based applications like swat
Source26: samba.pam
# catalog file for xsltproc
Source27: catalog.xml

# Fix build
Patch17: smbmount-sbin.patch
#Patch18: samba-3.0.30-autoconf-2.62.patch
#Patch19: samba-3.0.33-cifs.upcall-alt.patch
Patch20: lpq_parse.patch
Patch21: samba-inkscape-abspath.patch
Patch22: samba-makefile.patch
Patch23: samba-3.0.36-alt-libsmbclient-smbc_attr_server.patch

# ApplianceWare compatibility patch
Patch34: aw-smbstatus.patch

# Bugfixes:
#Patch42: samba-3.0.23-wins_nss.alt.patch
Patch43: smbumount-3.0.24-alt-options.patch

# Security fixes
Source51: CVE-2009-2813-advisory.txt
Source52: CVE-2009-2906-advisory.txt
Source53: CVE-2009-2948-advisory.txt

Patch54: samba-3.0.37-CVE-2010-2063.patch
Patch55: samba-3.0.37-CVE-2010-3069.patch
Patch56: samba-3.0.37-CVE-2011-0719.patch

Requires: %name-common = %version-%release

# due to sendfile64
BuildRequires: glibc-devel >= 2.2.6-alt0.10

# Automatically added by buildreq on Thu Apr 24 2003
BuildRequires: libattr-devel libldap-devel
BuildRequires: libncurses-devel libpam0-devel libpopt-devel libreadline-devel libsasl2 libssl-devel 
BuildRequires: zlib-devel libacl-devel 
BuildRequires: libkrb5-devel >= 1.3.1-alt2
BuildRequires: libkeyutils-devel >= 1.2-alt2

%if_enabled ccache
BuildRequires: gcc-common >= 1.4-alt1
%endif

%if_enabled cups
BuildRequires: libcups-devel libgnutls-devel
%define cups_serverbin %(cups-config --serverbin 2>/dev/null)
%endif

%if_enabled gendoc
BuildRequires: docbook-dtds latex2html inkscape
BuildRequires: docbook-style-xsl >= 1.73.2-alt1
BuildRequires: libxslt tetex-core tetex-latex xml-common xsltproc urw-fonts
BuildRequires: db2latex-xsl >= 0.8-alt0.pre1.2
BuildRequires: tetex-latex-listings tetex-latex-xcolor tetex-latex-unicode
%endif

%package common
Summary: Files used by both Samba servers and clients
Group: System/Servers
Provides: pam-winbind
Conflicts: %origname-common < 3.0
Obsoletes: samba3-common < %version-%release, samba-pdb-xml < %version-%release, samba-pdb-mysql < %version-%release, samba-pdb-pgsql < %version-%release
Provides: samba3-common 
Requires: libkrb5 >= 1.3.1-alt2
Requires(pre): shadow-utils, service

%package client
Summary: Samba (SMB/CIFS) client programs
Group: Networking/Other
PreReq: samba-client-control >= 0:1.2
PreReq: %name-common = %version-%release
Requires: libsmbclient = %version-%release
Obsoletes: smbfs
Obsoletes: samba3-client < %version-%release
Provides: samba3-client
Requires: keyutils >= 1.2-alt2

%package -n libsmbclient
Summary: Samba client shared library
Group: Development/C

%package -n libsmbclient-devel
Summary: Samba client shared library development headers
Group: Development/C
Requires: libcups-devel libncurses-devel libpam-devel libreadline-devel libssl openssl-devel
Requires: libacl-devel libsmbclient = %version-%release
Obsoletes: samba3-client-devel < %version-%release
Provides: samba3-client-devel
Provides: samba-client-devel

%package -n libsmbclient-devel-static
Summary: Samba client static library
Group: Development/C
Requires: libsmbclient-devel = %version-%release
Requires: libacl-devel-static
Obsoletes: samba3-client-devel-static < %version-%release
Provides: samba3-client-devel-static
Provides: samba-client-devel-static

%if_enabled cups
%package client-cups
Summary: Samba (SMB) support for CUPS
Group: Networking/Other
PreReq: cups
Requires: %name-client = %version-%release, cups
Obsoletes: samba3-client-cups < %version-%release
Provides: samba3-client-cups
%endif

%package vfs
Summary: Sample VFS modules (audit, recycle bin, netatalk, readonly) for Samba server
Group: System/Servers
Autoreq: yes
Requires: %name = %version-%release
Obsoletes: samba3-vfs < %version-%release
Provides: samba3-vfs

%package utils
Summary: Samba utils
Group: System/Servers
Autoreq: yes
Requires: %name-common = %version-%release

%package vfs-devel
Summary: Files needed for building VFS modules for Samba server
Group: Development/C
Obsoletes: samba3-vfs-devel < %version-%release
Provides: samba3-vfs-devel
Autoreq: no
Requires: %name-common = %version-%release
Requires: libncurses-devel libpam0-devel
Requires: kernel-headers libreadline-devel openssl-devel
Requires: libldap-devel libkrb5-devel libpopt-devel
Requires: libacl-devel libattr-devel

%package swat
Summary: SWAT -- Samba Web Administration Tool
Group: Security/Networking
Requires: %name = %version-%release
Obsoletes: samba3-swat < %version-%release
Provides: samba3-swat

%package doc
Summary: Samba documentation
Group: Networking/Other
Requires: %name-common = %version-%release
Obsoletes: samba3-doc < %version-%release
Provides: samba3-doc

%if_enabled python
%package -n python-module-samba
Summary: This package contains Python bindings to allow you to access various aspects of Samba
Group: System/Servers
Autoreq: yes
Requires: %name-common = %version-%release
%setup_python_module samba
%endif

%description
Samba provides an SMB server which can be used to provide network
services to SMB (sometimes called "Lan Manager") clients, including
various versions of MS Windows, OS/2, and other Linux machines. Samba
uses NetBIOS over TCP/IP (NetBT) protocols and does NOT need NetBEUI
(Microsoft Raw NetBIOS frame) protocol.

Samba 3.0 features an almost working NT Domain Control and Active
Directory support capabilities and includes the new SWAT (Samba Web
Administration Tool) that allows samba's smb.conf file to be remotely
managed using your favourite web browser. For the time being this is
being enabled on TCP port 901 via xinetd.

Please refer to the WHATSNEW.txt document for fixup information.  This
binary release includes encrypted password support.  Please read the
smb.conf file and ENCRYPTION.txt in the docs directory for
implementation details.

%description common
Samba-common provides files necessary for both the server and client
packages of Samba.

%description client
Samba-client provides some SMB clients, which complement the built-in
SMB filesystem in Linux. These allow the accessing of SMB shares.
Support for printing to SMB printers is in Samba-client-cups package.

%description -n libsmbclient
This is a shared library which implements RPC interfaces needed for
client-side of CIFS implementation.

%description -n libsmbclient-devel
Samba client-side development headers

%description -n libsmbclient-devel-static
Static version of Samba client library (libsmbclient)

%if_enabled cups
%description client-cups
Samba-client-cups provides pluggable backend for CUPS printing system.
It allows printing to SMB printers.
%endif

%description vfs
Samba-vfs provides prebuilt Samba server VFS modules (audit, recycle bin, netatalk, and cap).

%description vfs-devel
Samba3-vfs-devel provides files necessary for building Samba server
VFS modules (for example, audit or antivirus scanner modules).

%description utils
Samba utils

%description doc
This package contains Samba documentation.

%description swat
Samba3-swat provides Samba web administration tool which allows 
a Samba administrator to configure the complex smb.conf file
via web browser.

%if_enabled python
%description -n python-module-samba
This package contains Python bindings to allow you to access various aspects of Samba
%endif

%prep
%setup -q -n %origname-%version

%patch17 -p1
#%%patch18 -p1
#%%patch19 -p1
%patch20 -p1
%patch21 -p1
%patch22 -p1
%patch23 -p1
%patch43 -p1
%patch54 -p1
%patch55 -p1
%patch56 -p1

# Apply security patches

%if_enabled gendoc
# Import documentation from samba-docs CVS
    mkdir -p docs
pushd docs
    # Using Samba, 2nd ed.
    tar xjf %SOURCE15
popd
# Documentation sources
pushd docs-xml
	# remove man pages for things which we either don't build or don't have in Samba 3.0
	rm manpages-3/vfs_{gpfs,xattr_tdb}.*.xml
popd
%endif

# Correct documentation a bit.
find examples docs docs-xml -type f -print0 |
	xargs -r0 fgrep -l /usr/local/samba/var/log |
	xargs /usr/bin/subst 's|/usr/local/samba/var/log|%_logdir/%origname/log|g'
find examples docs docs-xml -type f -print0 |
	xargs -r0 egrep -l '/(opt|usr/local)/samba/(bin/|private/)?(smbd|nmbd|swat|winbindd)' |
	xargs /usr/bin/subst  's,/\(opt|usr/local\)/samba/\(bin/|private/\)?\(smbd|nmbd|swat|winbindd\),%_sbindir/\3,g'
find examples docs docs-xml -type f -print0 |
	xargs -r0 egrep -l '/(opt|usr/local)/samba/(bin/|private/)?(convert_smbpasswd|findsmb|make_printerdef|make_smbcodepage|make_unicodemap|nmblookup|rpcclient|smbclient|smbmount|smbpasswd|smbprint|smbspool|smbstatus|smbtar|smbumount|testparm|testprns|wbinfo)' |
	xargs /usr/bin/subst  's,/\(opt|usr/local\)/samba/\(bin/|private/\)?\(convert_smbpasswd|findsmb|make_printerdef|make_smbcodepage|make_unicodemap|nmblookup|rpcclient|smbclient|smbmount|smbpasswd|smbprint|smbspool|smbstatus|smbtar|smbumount|testparm|testprns|wbinfo\),%_bindir/\3,g'
find examples docs docs-xml -type f -print0 |
	xargs -r0 fgrep -l '/usr/local/samba/lib/smb.conf' |
	xargs /usr/bin/subst  's,/usr/local/samba/lib/smb.conf,%_sysconfdir/%origname/smb.conf,g'
find examples docs docs-xml -type f -print0 |
	xargs -r0 fgrep -l '/usr/local/samba/netlogon' |
	xargs /usr/bin/subst  's,/usr/local/samba/netlogon,%_localstatedir/%origname/netlogon,g'

%build
pushd source
./autogen.sh
export CPPFLAGS="$RPM_OPT_FLAGS -D_GNU_SOURCE -D_FILE_OFFSET_BITS=64 -D_LARGEFILE_SOURCE -DREPLACE_UTIMES=1"
export CFLAGS="$RPM_OPT_FLAGS -D_GNU_SOURCE -D_FILE_OFFSET_BITS=64 -D_LARGEFILE_SOURCE -DREPLACE_UTIMES=1"
# We do not use libcap due its wrong unconditional __u32 typedefs
export ac_cv_header_sys_capability_h=no

# Export CC=gcc if it CC is unset. This allows us to reuse ccache in BTE
[ -n "$CC" ] || export CC=gcc

# Use ccache to optimise rebuilds
%if_enabled ccache
export GCC_USE_CCACHE=1
export CCACHE_DIR=%__ccache_dir
%endif

%if_enabled debug
use_debug=" --enable-developer"
%endif

%configure $use_debug \
	--with-fhs \
	--libdir=%_libdir/%origname \
	--sysconfdir=%_sysconfdir/%origname \
	--localstatedir=%_var \
	--with-logfilebase=%_logdir/%origname \
	--with-configdir=%_sysconfdir/%origname \
	--with-privatedir=%_sysconfdir/%origname \
	--with-smbmount \
	--with-syslog \
	--with-ads \
	--with-pam \
	--with-sambabook=%_datadir/%origname/swat/using_samba \
	--with-mmap \
	--with-netatalk \
	--with-quotas \
	--with-acl-support \
	--with-aio-support \
	--with-winbind \
	--with-swatdir=%_datadir/%origname/swat \
	--with-piddir=%_lockdir \
	--with-lockdir=%_localstatedir/%origname \
	--with-shared-modules=idmap_rid,idmap_ad,vfs_prealloc,vfs_commit,vfs_catia,vfs_cacheprime,vfs_readahead \
	--with-libsmbclient=yes \
	--with-cifsupcall=yes \
%if_enabled python
	--with-python=python%__python_version
%endif


%__subst 's,^LIBDIR *=.*,LIBDIR = %_libdir/%origname,' Makefile

# Make prototypes using uniprocessor (important, proto does not work for SMP)
%__make  \
    proto

# Make Samba using SMP if available
%make  \
    everything nsswitch smbcacls smbcquotas \
    sharesec timelimit wins cac \
    libsmbclient libsmbsharemodes libmsrpc libaddns \
    bin/tdbbackup bin/tdbdump bin/vfstest bin/smbget \
%if_enabled python
    python_ext
%endif


popd

# Generate documentation if requested
%if_enabled gendoc
pushd docs-xml
export XML_CATALOG_FILES="file:///etc/xml/catalog file://$(pwd)/build/catalog.xml"
autoconf
./configure --with-samba-sources=../source
%__make smbdotconf/parameters.all.xml
%__make smbdotconf/parameters.global.xml
%__make smbdotconf/parameters.service.xml
%__make release

for i in Samba3-ByExample.pdf Samba3-Developers-Guide.pdf Samba3-HOWTO.pdf ; do
    mv output/$i ../docs/$i
done

rm -rf ../docs/manpages
mv output/manpages-3 ../docs/manpages
rm -rf ../docs/htmldocs/manpages
mv output/htmldocs/manpages-3 ../docs/htmldocs/manpages

rm -rf ../docs/htmldocs/Samba3-ByExample ../docs/htmldocs/Samba3-HOWTO ../docs/htmldocs/Samba3-Developers-Guide ../docs/htmldocs/index.html ../docs/htmldocs/samba.css

for i in Samba3-ByExample Samba3-Developers-Guide Samba3-HOWTO index.html samba.css ; do
    mv output/htmldocs/$i ../docs/htmldocs/$i
done

popd
%endif

# Do not distribute sources of documentation, they already included in src.rpm
%__rm -rf docs-xml

%install
pushd source
%make DESTDIR=%buildroot install-everything \
%if_enabled python
python_install
%endif


popd

%__mkdir -p %buildroot/sbin
%__mkdir -p %buildroot/%_sysconfdir/{%origname,logrotate.d,pam.d,xinetd.d}
%__mkdir -p %buildroot/%_initdir
%__mkdir -p %buildroot/%_localstatedir/%origname/winbindd_privileged
%__mkdir -p %buildroot/%_logdir/%origname
%__mkdir -p %buildroot/%_spooldir/%origname
%__mkdir -p %buildroot/%_localstatedir/%origname/{netlogon,profiles}
%__mkdir -p %buildroot/%_lib/security
%__mkdir -p %buildroot/%_datadir/%origname/vfs-devel/source
%__mkdir -p %buildroot/%_includedir


# Install samba-vfs-devel
pushd source
for i in `find . -name '*.h' -exec dirname '{}' \; |sort -u` ; do
    %__mkdir -p %buildroot%_datadir/%origname/vfs-devel/source/$i
    %__cp  $i/*.h %buildroot%_datadir/%origname/vfs-devel/source/$i/
done

%__cp include/libsmbclient.h %buildroot%_includedir/
popd

%__cp -r examples/VFS source/Makefile %buildroot%_datadir/%origname/vfs-devel/source/
sed -ri 's,^(src|build)dir=.*$,\1dir=.,' %buildroot%_datadir/%origname/vfs-devel/source/Makefile

for i in mksmbpasswd.sh
do
  %__install -m755 source/script/$i %buildroot%_bindir
done

for i in smbfilter log2pcap vfstest smbget \
         debug2html locktest locktest2 masktest msgtest nsstest smbtorture talloctort
do
  %__install -m755 source/bin/$i %buildroot%_bindir
done

install -pm700 source/bin/smbmnt %buildroot/sbin/
rm -f %buildroot%_bindir/smbmnt

%__install -m755 source/bin/libsmbclient.a %buildroot%_libdir/
%__mv %buildroot%_libdir/%origname/libsmbclient.so %buildroot%_libdir/libsmbclient.so.0
%__ln_s libsmbclient.so.0 %buildroot%_libdir/libsmbclient.so
%__rm -f %buildroot%_libdir/%origname/libsmbclient.a

# Install the nsswitch library extension file
for i in wins winbind ; do
  %__install -m755 source/nsswitch/libnss_$i.so %buildroot/%_lib
# Make link for Name Switch modules
  ( cd %buildroot/%_lib; %__ln_s libnss_$i.so libnss_$i.so.2; )
done 

# Install PAM modules
%__mkdir -p %buildroot/%_lib/security
%__install -m755 source/bin/pam_winbind.so %buildroot/%_lib/security
%__rm -rf %buildroot%_libdir/%origname/security

%if_enabled aw
	%__install -m644 %{SOURCE22} %buildroot%_sysconfdir/%origname/smb.conf
%else
	%__install -m644 %{SOURCE21} %buildroot%_sysconfdir/%origname/smb.conf
%endif
	# Remove 'root = administrator' mapping as it was obsoleted by 'admin users' option
	# and now by 'net rpc rights' management
	cat packaging/RHEL/setup/smbusers | grep -v root > smbusers
	%__install -m644 smbusers %buildroot%_sysconfdir/%origname/smbusers
	%__install -m755 packaging/RHEL/setup/smbprint %buildroot%_bindir
	%__install -m755 source/script/findsmb %buildroot%_bindir
%if_enabled aw
	%__install -m644 %{SOURCE24} %buildroot%_sysconfdir/pam.d/system-auth-winbind
%else
	%__install -m644 %{SOURCE23} %buildroot%_sysconfdir/pam.d/system-auth-winbind
%endif
	%__install -m644 %{SOURCE26} %buildroot%_sysconfdir/pam.d/samba
	%__install -m644 %SOURCE1 %buildroot%_sysconfdir/logrotate.d/%origname

	%__install -p -m755 -D %SOURCE7 %buildroot%_initdir/smb
	%__install -p -m755 -D %SOURCE8 %buildroot%_initdir/winbind
	%__ln_s  %_initdir/smb %buildroot%_sbindir/samba
	
# Fix mount.smbfs
	mv %buildroot%_bindir/smbmount %buildroot/sbin/mount.smbfs
	ln -s ../../sbin/mount.smbfs %buildroot%_bindir/smbmount
	mv %buildroot%_man8dir/{smbmount,mount.smbfs}.8
	ln -s mount.smbfs.8 %buildroot%_man8dir/smbmount.8

# Fix umount.smbfs
	mv %buildroot%_bindir/smbumount %buildroot/sbin/umount.smbfs
	ln -s ../../sbin/umount.smbfs %buildroot%_bindir/smbumount
	mv %buildroot%_man8dir/{smbumount,umount.smbfs}.8
	ln -s umount.smbfs.8 %buildroot%_man8dir/smbumount.8
	rm %buildroot%_sbindir/mount.smbfs

# Fix *mount.cifs
	mv %buildroot%_sbindir/*mount.cifs %buildroot/sbin/
	ln -s ../../sbin/mount.cifs %buildroot%_bindir/cifsmount
	ln -s mount.cifs.8 %buildroot%_man8dir/cifsmount.8
	ln -s ../../sbin/umount.cifs %buildroot%_bindir/cifsumount
	ln -s umount.cifs.8 %buildroot%_man8dir/cifsumount.8

# Fix *mount.cifs
	mv %buildroot%_sbindir/cifs.upcall %buildroot/sbin/

# Fix *mount.*fs perms
	chmod 700 %buildroot/sbin/{*mount.cifs,umount.smbfs,cifs.upcall}

	echo 127.0.0.1 localhost > %buildroot%_sysconfdir/%origname/lmhosts

%if_enabled cups
# Link smbspool to CUPS (does not require installed CUPS)
	%__install -d %buildroot%{cups_serverbin}/backend
	%__ln_s %_bindir/smbspool %buildroot%{cups_serverbin}/backend/smb
%endif

## xinetd support
	%__mkdir -p %buildroot/etc/xinetd.d
	%__install -m644 %SOURCE3 %buildroot%_sysconfdir/xinetd.d/swat

# menu support
	%__mkdir -p %buildroot%_menudir
	%__cat > %buildroot%_menudir/%origname << EOF
?package(%origname):command="gnome-moz-remote http://localhost:901/" needs="gnome" \
icon="swat.xpm" section="Configuration/Networking" title="Samba Configuration" \
longtitle="The Swat Samba Administration Tool"
?package(%origname):command="sh -c '\$BROWSER http://localhost:901/'" needs="x11" \
icon="swat.xpm" section="Configuration/Networking" title="Samba Configuration" \
longtitle="The Swat Samba Administration Tool"
EOF

%__mkdir -p %buildroot%_liconsdir %buildroot%_iconsdir %buildroot%_miconsdir

bzcat %SOURCE4 > %buildroot%_liconsdir/swat.xpm
bzcat %SOURCE5 > %buildroot%_iconsdir/swat.xpm
bzcat %SOURCE6 > %buildroot%_miconsdir/swat.xpm

# remove "left" docs
%__rm -rf docs/manpages{,-3} docs/htmldocs/Samba4-HOWTO docs/htmldocs/test
%__rm -f docs/Samba4-HOWTO.pdf docs/test.pdf 

# Install documentation.
%__mkdir -p %buildroot%_docdir/%origname-%version
install -p -m644 README Manifest WHATSNEW.txt Roadmap %buildroot%_docdir/%origname-%version
%__cp -a docs examples %buildroot%_docdir/%origname-%version
%if_enabled gendoc
%__cp -a docs/using_samba %buildroot%_datadir/%origname/swat/ ||:
%else
%__cp -a docs/htmldocs/using_samba %buildroot%_datadir/%origname/swat/ ||:
%endif

pushd %buildroot%_docdir/%origname-%version
find . -type f | xargs chmod 644
popd

# Do not install charset modules as we don't need them on ALT Linux
%__rm -f %buildroot%_libdir/%origname/charset/*
# Same for non-compiled SWAT translations
%__rm -f %buildroot%_libdir/%origname/*.msg

# This is a hack but we really don't need to bytecompile 
# Python code as we didn't build it.
%if_disabled python
unset RPM_PYTHON
%endif

%post
# Add a unix group for samba machine accounts
/usr/sbin/groupadd -frg 421 machines
if [ $1 -gt 1 ] ; then
    # We stopped services previously at %%pre of %name-common if they were running
    # It is time to start them again
    if [ -f %_localstatedir/%origname/wnbstopped ] ; then
	/sbin/service winbind start 
	%__rm -f %_localstatedir/%origname/wnbstopped
    fi
    if [ -f %_localstatedir/%origname/smbstopped ] ; then 
	/sbin/service smb start
	%__rm -f %_localstatedir/%origname/smbstopped
    fi
else
    %post_service smb
fi

%pre
# Transfer databases into different location
if [ $1 -gt 1 ] ; then
    # Migrate tdb's from /var/lock/samba (taken from official samba spec file):
    if [ -d %_lockdir/%origname ]; then
        echo "Moving tdb files in /var/lock/samba/*.tdb to /var/lib/samba/*.tdb"
        for i in %_lockdir/%origname/*.tdb; do
	    biname=$(basename $i)
	    wrongname=$(ls -1 %_localstatedir/*.tdb 2>/dev/null |grep $biname)
	    [ -n "$wrongname" ] || continue
	    if [ -f $wrongname ] ; then
		newname="%_localstatedir/%origname/$biname"
    		echo "Moving $wrongname to $newname (fixing relocation error in 3.0.2a-alt2)"
    		%__mv $wrongname $newname
	    else
		if [ -f $i ] ; then
		    newname="%_localstatedir/%origname/$biname"
    		    echo "Moving $i to $newname"
    		    %__mv $i $newname
		fi
	    fi
	done
    fi

    # Migrate tdb's from /var/cache/samba (taken from official samba spec file):
    if [ -d %_cachedir/%origname ]; then
	echo "Moving tdb files in /var/cache/samba/*.tdb to /var/lib/samba/*.tdb"
	for i in %_cachedir/%origname/*.tdb; do
	    biname=$(basename $i)
	    wrongname=$(ls -1 %_localstatedir/*.tdb 2>/dev/null |grep $biname)
	    [ -n "$wrongname" ] || continue
	    if [ -f $wrongname ] ; then
		newname="%_localstatedir/%origname/$biname"
    		echo "Moving $wrongname to $newname (fixing relocation error in 3.0.2a-alt2)"
    		%__mv $wrongname $newname
	    else
		if [ -f $i ]; then
		    newname="%_localstatedir/%origname/$biname"
    		    echo "Moving $i to $newname"
    		    %__mv $i $newname
		fi
	    fi
	done
    fi

    # Remove the transient tdb files (modified from version in off. samba spec:
    for TDB in brlock unexpected locking messages; do
	    if [ -e %_localstatedir/%origname/$TDB.tdb ]; then
		    %__rm -f %_localstatedir/%origname/$TDB.tdb;
	    fi;
    done

    if [ -d %_lockdir/%origname ]; then
	%__rm -rf %_lockdir/%origname
    fi

    # Hack to fix upgrade from ancient versions.
    if [ $1 -gt 1 -a ! -e /etc/inetd.conf ]; then
	touch /etc/inetd.conf
    fi
    
fi

%pre common
/usr/sbin/groupadd -r -f winbind 
if [ $1 -gt 1 -a -s /etc/samba/smb.conf -a -f %_initdir/smb -a -f %_initdir/winbind ]; then
    smbstopped=$(/sbin/service smb status|grep stopped)
    wnbstopped=$(/sbin/service winbind status|grep stopped)
    [ -n "$smbstopped" ] || /sbin/service smb stop
    [ -n "$wnbstopped" ] || /sbin/service winbind stop
    [ -n "$smbstopped" ] || touch %_localstatedir/%origname/smbstopped
    [ -n "$wnbstopped" ] || touch %_localstatedir/%origname/wnbstopped
fi

%post common
if [ $1 -eq 1 ] ; then
    %post_service winbind
fi

%preun common
%preun_service winbind

%post swat
if [ -f %_lockdir/subsys/xinetd ]; then
	/sbin/service xinetd sreload || :
fi

%preun
%preun_service smb
if [ $1 = 0 ] ; then
    if [ -e %_localstatedir/%origname/browse.dat ]; then
	    %__rm -f %_localstatedir/%origname/browse.dat
    fi
    if [ -e %_localstatedir/%origname/wins.dat ]; then
	    %__rm -f %_localstatedir/%origname/wins.dat
    fi
    if [ -d %_logdir/%origname ]; then
	    %__rm -rf %_logdir/%origname/*
    fi
    if [ -d %_localstatedir/%origname ]; then
	    %__rm -rf %_localstatedir/%origname/*
    fi
fi

%postun
# Remove swat entry from xinetd
if [ $1 = 0 -a -f %_sysconfdir/xinetd.conf -a -f %_lockdir/subsys/xinetd ]; then
	/sbin/service xinetd sreload || :
fi


%triggerpostun -- samba < 1.9.18p7
if [ $1 != 0 ]; then
	/sbin/chkconfig --add smb
fi

%triggerpostun -- samba < 2.0.10
if [ $1 != 0 ]; then
	[ -d %_lockdir/%origname ] || %__mkdir -m755 %_lockdir/%origname
	[ -d %_spooldir/%origname ] || %__mkdir -m1777 %_spooldir/%origname
	[ ! -s %_sysconfdir/inetd.conf ] || %__chmod 644 %_sysconfdir/services %_sysconfdir/inetd.conf
else
	[ -s %_sysconfdir/inetd.conf ] || rm -f %_sysconfdir/inetd.conf
fi

%pre client
%pre_control cifsmount cifsumount smbmount

%post client
%post_control -s wheelonly cifsmount cifsumount smbmount

%files swat
%config(noreplace) %_sysconfdir/xinetd.d/swat
%_sbindir/swat
%attr(-,root,root) %_datadir/%origname/swat
%_man8dir/swat.8*
%_menudir/%origname
%_miconsdir/*.xpm
%_liconsdir/*.xpm
%_iconsdir/*.xpm

%files
%_sbindir/%origname
%_sbindir/smbd
%_sbindir/nmbd
%_bindir/smbstatus
%_bindir/pdbedit
%_bindir/profiles
%_bindir/eventlogadm
%_libdir/%origname/libmsrpc.so
%attr(-,root,root) %config(noreplace) %_sysconfdir/%origname/smbusers
%attr(-,root,root) %config %_initdir/smb
%_man1dir/smbstatus.1*
%_man1dir/profiles.1*
%_man8dir/smbd.8*
%_man8dir/nmbd.8*
%_man8dir/pdbedit.8*
%attr(775,root,root) %dir %_localstatedir/%origname/netlogon
%attr(775,root,root) %dir %_localstatedir/%origname/profiles
%attr(1777,root,root) %dir %_spooldir/%origname
%dir %_docdir/%origname-%version
%_docdir/%origname-%version/[A-Z]*
%_man8dir/eventlogadm.8*
%_man8dir/idmap_*.8*
				
				

%files client
%_bindir/smbfilter
/sbin/smbmnt
/sbin/mount.cifs
/sbin/mount.smbfs
/sbin/umount.cifs
/sbin/umount.smbfs
/sbin/cifs.upcall
%_bindir/cifs*mount
%_bindir/smb*mount
%_man8dir/smbmnt.8*
%_man8dir/cifs*mount.8*
%_man8dir/smb*mount.8*
%_man8dir/*mount.cifs.8*
%_man8dir/*mount.smbfs.8*
%_bindir/nmblookup
%_bindir/findsmb
%_bindir/smbprint
%_bindir/smbtar
%_bindir/smbspool
%_bindir/smbclient
%_bindir/smbtree
%_bindir/smbcacls
%_bindir/smbcquotas
%_bindir/rpcclient
%_man1dir/smbtar.1*
%_man1dir/smbtree.1*
%_man1dir/smbclient.1*
%_man1dir/nmblookup.1*
%_man1dir/findsmb.1*
%_man1dir/smbcacls.1*
%_man1dir/smbcquotas.1*
%_man1dir/rpcclient.1*
%_man8dir/smbspool.8*
%_man7dir/libsmbclient.7*
%_man8dir/cifs.upcall.8*

%files -n libsmbclient
%_libdir/*.so.*
%_libdir/%origname/libsmbsharemodes.so

%files -n libsmbclient-devel-static
%_libdir/*.a

%files -n libsmbclient-devel
%_includedir/*.h
%_libdir/*.so

%if_enabled cups
%files client-cups
# Link of smbspool to CUPS
%{cups_serverbin}/backend/smb
%endif

%files common
#%%_bindir/editreg
%_bindir/mksmbpasswd.sh
%_bindir/log2pcap
%_bindir/net
%_bindir/ntlm_auth
%_bindir/smbcontrol
%_bindir/smbpasswd
%_bindir/tdbbackup
%_bindir/tdbtool
%_bindir/tdbdump
%_bindir/testparm
#%%_bindir/testprns
%_bindir/wbinfo
%_bindir/smbget
%_sbindir/winbindd
%attr(755,root,root) /%_lib/security/*
%attr(755,root,root) /%_lib/libnss*
%dir %_sysconfdir/%origname
%attr(-,root,root) %config(noreplace) %_sysconfdir/%origname/smb.conf
%attr(-,root,root) %config(noreplace) %_sysconfdir/%origname/lmhosts
%attr(-,root,root) %config %_initdir/winbind
%attr(644,root,root) %config(noreplace) %_sysconfdir/pam.d/system-auth-winbind
%attr(644,root,root) %config(noreplace) %_sysconfdir/pam.d/samba
#%%_man1dir/editreg.1*
%_man1dir/log2pcap.1*
%_man1dir/ntlm_auth.1*
%_man1dir/smbcontrol.1*
%_man1dir/testparm.1*
#%%_man1dir/testprns.1*
%_man5dir/smb.conf.5*
%_man5dir/smbpasswd.5*
%_man5dir/smbgetrc.5*
%_man5dir/lmhosts.5*
%_man1dir/wbinfo.1*
%_man1dir/smbget.1*
%_man7dir/samba.7*
%_man8dir/net.8*
%_man8dir/smbpasswd.8*
%_man8dir/tdbbackup.8*
%_man8dir/tdbtool.8*
%_man8dir/tdbdump.8*
%_man8dir/winbindd.8*
%_man7dir/pam_winbind.7*
%dir %_libdir/%origname
%dir %_libdir/%origname/vfs
%dir %_libdir/%origname/pdb
%dir %_libdir/%origname/auth
%dir %_libdir/%origname/charset
%dir %_libdir/%origname/idmap
%dir %_libdir/%origname/rpc
%dir %_libdir/%origname/nss_info
%_libdir/%origname/*.dat
%dir %_localstatedir/%origname
%_libdir/%origname/auth/*.so
%_libdir/%origname/idmap/*.so
%_libdir/%origname/nss_info/*.so
%attr(750,root,adm) %dir %_logdir/%origname
%attr(-,root,root) %config(noreplace) %_sysconfdir/logrotate.d/%origname
%attr (750,root,winbind) %dir %_localstatedir/%origname/winbindd_privileged

%files utils
%_bindir/vfstest
%_bindir/debug2html
%_bindir/locktest
%_bindir/locktest2
%_bindir/masktest
%_bindir/msgtest
%_bindir/nsstest
%_bindir/smbtorture
%_bindir/talloctort
%_man1dir/vfstest.1*

%if_enabled python
%files -n python-module-samba
%doc source/python/README
%doc source/python/examples
%doc source/python/gprinterdata
%doc source/python/gtdbtool
%doc source/python/gtkdictbrowser.py
%python_sitelibdir/%name
%python_sitelibdir/Samba_Python_Extensions*
%endif
 
%files doc
%dir %_docdir/%origname-%version
%_docdir/%origname-%version/[a-z]*

%files vfs
%_libdir/%origname/vfs/*
%_man8dir/vfs*.8*

%files vfs-devel
%dir %_datadir/%origname/vfs-devel
%_datadir/%origname/vfs-devel/*

%changelog
* Mon Feb 28 2011 Vitaly Kuznetsov <vitty@altlinux.ru> 3.0.37-alt4.M50P.1
- CVE-2011-0719

* Mon Sep 13 2010 Vitaly Kuznetsov <vitty@altlinux.ru> 3.0.37-alt3.M50P.1
- CVE-2010-3069

* Wed Jun 16 2010 Vitaly Kuznetsov <vitty@altlinux.ru> 3.0.37-alt2.M50P.1
- CVE-2010-2063

* Thu Oct 01 2009 Alexander Bokovoy <ab@altlinux.org> 3.0.37-alt1
- Security fixes:
    + CVE-2009-2813
    + CVE-2009-2906
    + CVE-2009-2948

* Sun Sep 20 2009 Dmitry V. Levin <ldv@altlinux.org> 3.0.36-alt3.1
- NMU.
- Uncompressed main tarball to ease its signature verification and
  to decrease srpm size.
- Resurrected libsmbclient smbc_attr_server fix.

* Tue Sep 15 2009 Alexander Bokovoy <ab@altlinux.org> 3.0.36-alt3
- Fixed:
    + #20167: delete restart from logrotate script
    + install proper build documentation, override stock one

* Mon Sep 14 2009 Alexander Bokovoy <ab@altlinux.org> 3.0.36-alt2
- Do not wait for Inkscape update, fix it by using abspath in paths passed to Inkscape

* Fri Aug 07 2009 Alexander Bokovoy <ab@altlinux.org> 3.0.36-alt1
- 3.0.36, final version in 3.0 series

* Tue Apr 07 2009 Alexander Bokovoy <ab@altlinux.org> 3.0.33-alt4
- Fix #19519: cover case when no options where specified

* Mon Mar 30 2009 Alexander Bokovoy <ab@altlinux.org> 3.0.33-alt3
- Back out static qualifier for smbc_attr_server, it is still used
  separately from libsmbclient in internal API of libmsrpc.

* Mon Mar 30 2009 Alexander Bokovoy <ab@altlinux.org> 3.0.33-alt2
- Backport cifs.upcall and updated mount.cifs/umount.cifs from 3.3 branch
  Fixed:
  + #19199
  + #15875
  + #17700
  + #18638

* Thu Nov 27 2008 Alexander Bokovoy <ab@altlinux.org> 3.0.33-alt1
- Security release 3.0.33:
  + CVE 2008-4314

* Sat Jul 19 2008 Alexander Bokovoy <ab@altlinux.org> 3.0.31-alt1
- 3.0.31:
  + added patches from v3-0-test
  + removed patch #44 (post 3.0.30 patches, accumulated in v3-0-test already)
  Fixed:
  + #16218
  + #16052
  + #4874
  + #16213

* Tue Jul 01 2008 Anton Farygin <rider@altlinux.ru> 3.0.30-alt3.1
- fixed build with autoconf-2.62
- fixed python requires

* Sat May 31 2008 Alexander Bokovoy <ab@altlinux.org> 3.0.30-alt3
- Fixed:
  + #5489 in Samba Bugzilla (Winbindd on PDC, jra)
  + #5504 in Samba Bugzilla (Winbindd wrong SIGTERM handling, jra)
  + Fix joining NT4 domains (gd)

* Thu May 29 2008 Alexander Bokovoy <ab@altlinux.org> 3.0.30-alt2
- Update documentation build to properly use networkless setup 

* Wed May 28 2008 Alexander Bokovoy <ab@altlinux.org> 3.0.30-alt1
- 3.0.30
- Security update for CVE-2008-1105

* Sun May 25 2008 Alexander Bokovoy <ab@altlinux.org> 3.0.29-alt1
- 3.0.29
- Fixed:
  + post release fixes from Steven Danneman (8dc4e979776)
  + removed ldb* manpages as ldb is only in Samba 3.2
  + removed manpages for VFS modules that are only in Samba 3.2
    or not supported in our Samba 3.0 build

* Sat Apr 12 2008 Alexander Bokovoy <ab@altlinux.org> 3.0.28a-alt3
- v3-0-test: Fixed bugs #5386, #5366 (Samba.org bugzilla)
- Removed rpcclient from samba-common, moved to samba-client.

* Fri Apr 11 2008 Alexander Bokovoy <ab@altlinux.org> 3.0.28a-alt2
- Accumulate post-3.0.28a fixes from 3-0-test git branch
- Add source/Makefile to samba-vfs-devel to satisfy out-of-tree builds of samba-vscan
- Improve documentation build, get back smbmount manpages
- Improve python bindings sub-package

* Tue Mar 25 2008 Alexander Bokovoy <ab@altlinux.org> 3.0.28a-alt1
- 3.0.28a
- Fixed:
  + pam_smbpass build
  + documentation build, including manpages
  + cups dependencies (libgnutls-devel is required to build any cups 
    client but libcups-devel lacks dependency)

* Fri Jan 25 2008 Grigory Batalov <bga@altlinux.ru> 3.0.28-alt1.1
- Rebuilt with python-2.5.

* Mon Dec 10 2007 Alexander Bokovoy <ab@altlinux.org> 3.0.28-alt1
- Fixed:
  + CVE-2007-6015:
  == Specifically crafted GETDC mailslot requests
  == can trigger a boundary error in the domain
  == controller GETDC mail slot support which
  == can be remotely exploited to execute arbitrary
  == code.
  + fix error path in local groups' addition (Volker)

* Mon Nov 26 2007 Alexander Bokovoy <ab@altlinux.org> 3.0.27a-alt1
- Fixed:
  + smbfs accesses to Samba 3.0.27 caused disruptions on server side in some situations

* Thu Nov 15 2007 Alexander Bokovoy <ab@altlinux.org> 3.0.27-alt1
- Security release 3.0.27:
  + CVS-2007-4572
    Stack buffer overflow in nmbd's logon request processing.
  + CVE-2007-5398
    Remote code execution in Samba's WINS server daemon (nmbd) 
    when processing name registration followed name query requests.
- Updated set of loadable modules:
  + added nss_info/rfc2307, nss_info/sfu, idmap/ad
- General spec file clean up
- Keep dependency on kernel-headers-std until Branch and Sisyphus policies
  would be synchronized

* Sun Nov 11 2007 Alexander Bokovoy <ab@altlinux.org> 3.0.26a-alt2
- Use git to handle the package
  + Fix #13210 (and a number of similar unreported bugs), now
    all pdb, auth, rpc, and idmap are included into %name-common

* Tue Sep 11 2007 Alexander Bokovoy <ab@altlinux.org> 3.0.26a-alt1
- Bugfix release
- Includes security fix for CVE-2007-4138

* Sun Sep 02 2007 Alexander Bokovoy <ab@altlinux.org> 3.0.25c-alt1
- New release
- Removed:
  + Python linkage patch, merged to upstream
- Added:
  + Post-release Python build fix patch from rev.24635 (Volker)

* Mon May 14 2007 Alexander Bokovoy <ab@altlinux.org> 3.0.25-alt1
- New release
- Security fixes for CVE-2007-2444, CVE-2007-2446, and CVE-2007-2447:
  + CVE-2007-2444
    Versions: Samba 3.0.23d - 3.0.25pre2
    Local SID/Name translation bug can result in user privilege elevation
  + CVE-2007-2446
    Versions: Samba 3.0.0 - 3.0.24
    Multiple heap overflows allow remote code execution
  + CVE-2007-2447
    Versions: Samba 3.0.0 - 3.0.24
    Unescaped user input parameters are passed as
    arguments to /bin/sh allowing for remote command
    execution
- Removed:
  + smbwrapper, as it is not supported anymore
- Fixed:
  + python build w.r.t. -pie

* Wed Apr 18 2007 Dmitry V. Levin <ldv@altlinux.org> 3.0.24-alt3
- Fixed /var/log/samba directory permissions (#5223).
- smbumount: Added mount options support (#11554).

* Tue Apr 17 2007 Dmitry V. Levin <ldv@altlinux.org> 3.0.24-alt2
- {smb,winbind}.init: Disabled by default (#11513).
- Relocated {mount,umount}.{cifs,smbfs} (#11124).
- Fixed -common %%pre script (#10799).

* Sat Feb 03 2007 Alexander Bokovoy <ab@altlinux.ru> 3.0.24-alt1
- 3.0.24: 3.0.23d plus security fixes:
  - CVE-2007-0454, only this one is relevant to ALT Linux distribution
  - CVE-2007-0453
  - CVE-2007-0452
- Fixed:
  - #10116, #3092

* Sat Jul 22 2006 Alexander Bokovoy <ab@altlinux.ru> 3.0.23a-alt1
- 3.0.23a 
- Removed:
  - XML, MySQL, and PgSQL experimental SAM backends (separate now)
- Fixed:
  - nss_wins lacked proper dependcies, fixed.

* Fri Jul 21 2006 Alexander Bokovoy <ab@altlinux.ru> 3.0.23-alt1
- 3.0.23
- Fixed:
  - get user token properly when winbindd is down (r17016, vlendec)
- Removed number of old patches and automount/NIS support
- Disabled documentation build by default, replaced by pre-built version

* Sun Feb 26 2006 Alexander Bokovoy <ab@altlinux.ru> 3.0.21c-alt1
- 3.0.21c 

* Tue Jan 31 2006 Vladimir Lettiev <crux@altlinux.ru> 3.0.21b-alt1
- 3.0.21b

* Sun Jan 08 2006 Vladimir Lettiev <crux@altlinux.ru> 3.0.21a-alt1
- 3.0.21a
- Fixed bugs: #6289, #6462, #7254
- hackaround smbcontrol bug (nmbd still exist after stopping service)

* Wed Dec 21 2005 Vladimir Lettiev <crux@altlinux.ru> 3.0.21-alt1
- 3.0.21
- use samba sources from svn branch SAMBA_3_0_RELEASE

* Wed Oct 19 2005 Vladimir Lettiev <crux@altlinux.ru> 3.0.21-alt0.pre1
- 3.0.21pre1
- updated samba-docs to 840 revision

* Sun Oct 16 2005 Vladimir Lettiev <crux@altlinux.ru> 3.0.20b-alt1
- 3.0.20b

* Fri Sep 16 2005 Vladimir Lettiev <crux@altlinux.ru> 3.0.20-alt2
- Post release patches:
	+ group_enum_v3 (ldap)
	+ AIX 5 & Win98 endless directory loop (samba bugs: #3010)
	+ Winbindd
	+ RegCreateKeyEx() Failures
	+ Usrmgr.exe and Groups
	+ net rpc shutdown (samba bugs: #3080)
	+ DOS Applications (samba bugs: #3044, #3060)
	+ x64 crashes
- Additional patches:
	+ statvfs-SAMBA-3.patch (VFS API's statvfs abstraction)

* Mon Aug 29 2005 Vladimir Lettiev <crux@altlinux.ru> 3.0.20-alt1
- 3.0.20
- added python module
- added utils package

* Wed Apr 20 2005 Alexander Bokovoy <ab@altlinux.ru> 3.0.14a-alt2
- Fixed:
    + the documentation Makefile phony targets
    + #6573
- 

* Sun Apr 17 2005 Alexander Bokovoy <ab@altlinux.ru> 3.0.14a-alt1
- 3.0.14a
- Fixed:
    + effective group id should be checked on delete requests too (jra)
    + a number of issues with documentation build
- Removed:
    + bin/editreg build as utils/editreg.c is too broken atm.
- Added:
    + pam_winbind manual page

* Thu Dec 16 2004 Dmitry V. Levin <ldv@altlinux.org> 3.0.10-alt1
- 3.0.10

* Sun Nov 21 2004 Vladimir Lettiev <crux@altlinux.ru> 3.0.9-alt1
- 3.0.9
- Fixed:
    + Problem updating roaming user profiles
    + Crash in smbd when printing from a Windows 9x client
    + Unresolved symbols in libsmbclient
    + Do not fail on setting file attributes with acl support enabled
- Updated samba-docs (SVN 20041121)
- Rediffed patches 17,38,40

* Sat Nov 13 2004 ALT QA Team Robot <qa-robot@altlinux.org> 3.0.8-alt1.1
- Rebuilt with openldap-2.2.18-alt3.

* Wed Nov 10 2004 Vladimir Lettiev <crux@altlinux.ru> 3.0.8-alt1
- 3.0.8 (include fix for CAN-2004-0930 -- smbd remote DoS vulnerability)

* Mon Nov 01 2004 Vladimir Lettiev <crux@altlinux.ru> 3.0.8-alt0.pre2.1
- 3.0.8pre2

* Wed Oct 27 2004 Vladimir Lettiev <crux@altlinux.ru> 3.0.8-alt0.pre1.2
- build documentation in pdf format (db2latex-xsl >= 0.8-alt0.pre1.2 required)
- gpl.tex replaced by gpl.xml

* Thu Sep 30 2004 Vladimir Lettiev <crux@altlinux.ru> 3.0.8-alt0.pre1.1
- 3.0.8pre1
- removed patches 1,2 (fixes included in upstream code)
- new documentation from cvs (20040930)
- added build dependency - dia (to generate png images)
- removed patch 20 (we don't build documentation in pdf format)
- changed patch 40 (to suit to small change in makefile)
- install section: corrected libsmclient.(a|so) installation
- new files: smbgetrc.5 (man), full_audit.so (vfs)

* Mon Sep 13 2004 Dmitry V. Levin <ldv@altlinux.org> 3.0.5-alt2
- Moved control files to separate package.
- Keep samba client helpers at mode "restricted" in the package,
  but default it to "wheelonly" in %%post when the package is
  first installed.  This avoids a race and fail-open behaviour.

* Sat Sep 11 2004 Dmitry V. Levin <ldv@altlinux.org> 3.0.5-alt1
- Applied patches from Gerald Carter.
- Fixed cifsmount.control.

* Tue Jul 20 2004 Stanislav Ievlev <inger@altlinux.org> 3.0.5-alt0.1
- 3.0.5

* Tue May 11 2004 ALT QA Team Robot <qa-robot@altlinux.org> 3.0.3-alt1.1
- Rebuilt with openssl-0.9.7d.

* Thu May 06 2004 Alexander Bokovoy <ab@altlinux.ru> 3.0.3-alt1
- Fixed:
    + smbwrapper breakage with 2.4 and 2.6 kernels (SYS_utimes)
    + MS04-012 security update broke Samba 3.0.3, fix it (Jeremy, Andrew Bartlett)
    + Rebuild with glibc 2.3 to get correct versioning for sendfile64

* Thu Apr 22 2004 Alexander Bokovoy <ab@altlinux.ru> 3.0.3-alt0.7
- 3.0.3RC1
- Fixed:
    + segfault in winbind (Volker Lendecke)
    + Adding a domain user to a XP local group did a lsalookupname on
      the user without domain prefix, and this then failed (Volker Lendecke)

* Wed Apr 14 2004 Alexander Bokovoy <ab@altlinux.ru> 3.0.3-alt0.6
- Fixed:
    + add missed provides: samba-client-devel for libsmbclient-devel subpackage

* Thu Apr 08 2004 Alexander Bokovoy <ab@altlinux.ru> 3.0.3-alt0.5
- Fixed:
    + #3937 (already fixed in 3.0.3-alt0.3)
- Updated:
    + Large documentation update:
	- Samba-3 by Example book by John Terpstra added
	- The Official Samba 3 HOWTO is complete now (with additional 5 chapters)

* Tue Apr 06 2004 Alexander Bokovoy <ab@altlinux.ru> 3.0.3-alt0.4
- Fixed:
    + #3923: separate libsmbclient shared library into libsmbclient package

* Tue Apr 06 2004 Alexander Bokovoy <ab@altlinux.ru> 3.0.3-alt0.3
- 3.0.3pre2
- Added:
    + ChangeLog for new subversion repository is in ChangeLog.svn.SAMBA_3_0.bz2
      Old ChangeLog is in ChangeLog.SAMBA_3_0.bz2
- Fixed:
    + smbfs issue (unconditional Tree Disconnect issued in cli_shutdown)
    + some mount.cifs fixes (Steve French)
    + postin scriplet fix in %name-common

* Fri Mar 26 2004 Alexander Bokovoy <ab@altlinux.ru> 3.0.3-alt0.2
- Fixed:
    + first time install was included into upgrade logic path

* Thu Mar 25 2004 Alexander Bokovoy <ab@altlinux.ru> 3.0.3-alt0.1
- 3.0.3pre1

* Wed Mar 17 2004 Alexander Bokovoy <ab@altlinux.ru> 3.0.2a-alt8
- Rebuild against Sisyphus
- Applied another pile of fixes from SAMBA_3_0 before 3.0.3pre1

* Tue Mar 16 2004 Alexander Bokovoy <ab@altlinux.ru> 3.0.2a-alt7
- Fixed:
    + Activate '\\' check in check_path_syntax() only for unix charsets
      that are known for having '\\' as second byte of multibyte character

* Fri Mar 12 2004 Alexander Bokovoy <ab@altlinux.ru> 3.0.2a-alt6
- Fixed:
    + resolve_wildcards() to use pstring instead of fstring
      because otherwise UTF-8 encoded name does not fit a buffer 
      (567 bytes in 255)
    + and smbclient too, use pstring instead fstring where filenames
      are processed
    + also, string overflow in vfs_recycle

* Wed Mar 10 2004 Alexander Bokovoy <ab@altlinux.ru> 3.0.2a-alt5
- 3.0.2a+fixes from SAMBA_3_0 branch for charset handling
- Fixed:
    + Wrap database relocation into preinstall scriptlet and run it
      only if we are upgrading from previous version. Make sure
      that smb and winbind services are correctly switched off and
      on before and after migration if needed.

* Tue Mar 02 2004 Alexander Bokovoy <ab@altlinux.ru> 3.0.2a-alt4
- Fixed:
    + Base relocation corner case with bases relocated at wrong location
      on previous update
- Added:
    + control facilities for cifsfs and smbfs now honor existing states on update

* Fri Feb 27 2004 Alexander Bokovoy <ab@altlinux.ru> 3.0.2a-alt3
- Fixed:
    + stupid problem with relocating databases into wrong location
    + name typo on cifsmount control facility

* Tue Feb 24 2004 Alexander Bokovoy <ab@altlinux.ru> 3.0.2a-alt2
- Fixed:
    + winbind and smb services are useful on level 5 too

* Sun Feb 15 2004 Alexander Bokovoy <ab@altlinux.ru> 3.0.2a-alt1
- Final 3.0.2a
- Updated:
    + documentation build is made non-interactive and does not
      require network access now
- Added:
    + %name-pdb-pgsql for PostgreSQL passdb backend
    + smbget in %name-common for wget-like resource fetches
- Removed:
    + utmp support in favor of smbstatus due to performance issues

* Thu Dec 11 2003 Alexander Bokovoy <ab@altlinux.ru> 3.0.1-alt0.3
- Final 3.0.1RC2
- Fixed:
    + #281, #875 in Samba Bugzilla
    + Uninitialized variable in passdb/passdb.c (Andy Polyakov)

* Wed Dec 10 2003 Alexander Bokovoy <ab@altlinux.ru> 3.0.1-alt0.2
- 3.0.1RC2
- Fixed:
    + Installation paths for manpages
    + Numerous links in both PDF and HTML versions of HOWTO Collection
- Added:
    + Build Samba-HOWTO-Collection and Samba-Developers-Guide in HTML
      explicitly

* Fri Dec 05 2003 Alexander Bokovoy <ab@altlinux.ru> 3.0.1-alt0.1
- 3.0.1rc1
- Added:
    + editreg, log2pcap, vfstest and their manpages
- Changed:
    + return to samba-* series, obsolete samba3-* ones
- Fixed:
    + samba-docs build for building with recent libxslt/xsltproc
    + Japanese and Turkish localisation for SWAT

* Thu Nov 27 2003 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt46.2
- Since in AW there is no interactive user logons via PAM,
  system-auth-winbind does not to take care of pam_mkhomedir calls

* Fri Oct 31 2003 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt46.1
- Rebuild for ALT Linux Sisyphus

* Thu Oct 30 2003 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt46
- Added:
   + Specs for x86 and IQ31244 development board are integrated

* Thu Oct 30 2003 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt45
- Fixed:
   + Fixes to check for wraps which could cause coredumps (jra)

* Tue Oct 28 2003 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt44
- Added:
   + 3.0.1pre1
   + documentations from samba-docs CVS
- Fixed:
   + charset conversion in rNetServerGetInfo RAP call (ab)
   + script/installbin.sh fix updated

* Fri Oct 24 2003 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt43
- Changed:
   + oem:version support now works for any combinations of OEM and version

* Fri Oct 10 2003 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt42
- Fixed:
   + Bug #3144 (http://bugzilla.altlinux.ru)

* Tue Sep 30 2003 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt41
- 3.0.0 final + post release fixes
- Added:
   + cifsvfs mount helper and control(8) support to it
   + Use only LinuxPAM and ignore OpenPAM
- Fixed:
   + SWAT tables (#413 in Samba's bugzilla, tpot)
   + Fix broken wins hook functionality (#528 in Samba's bugzilla, tpot)
   + Fix for valid users = %%S in homes share (jra)
   + documentation updated

* Fri Sep 19 2003 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt40
- Fixed:
   + The -P option to smbclient no longer works - update all 
     smbprint scripts to remove it. (#473 in Samba's bugzilla, tpot)
   + 32 bit field in the user structs is actually 2 16-bit fields,
     bad_password_count and logon_count. JRA.

* Thu Sep 18 2003 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt39
- Fixed
   + default ACEs
   + Fix for #470 - unable to display SIDs in ACLs. JRA.

* Wed Sep 17 2003 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt38
- RC4+fixes
- Fixed:
   + NTLMv2 signing bug (#442 in Samba's bugzilla) which prevented
     mixed mode domain join

* Fri Sep 12 2003 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt37
- Back out NTLMv2 patch as suspect to mixed mode domain join failure

* Thu Sep 11 2003 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt36
- Fixed:
   + LDAP code didn't convert from/to UTF-8 in all cases (JRA)

* Wed Sep 10 2003 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt35
- Fixed:
   + getgrouplist() enabler is moved to separate patch 39
   + machine account password change (jra)
   + typo fix which caused CPU spin (jra, Markus Ungermann)
- Added:
   + ability to change vendor string through smb.conf (oem: version)

* Wed Sep 10 2003 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt34
- Fixed:
   + Optimisation in iconv(3) usage paths which broke non-ASCII (jra)

* Tue Sep 09 2003 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt33
- RC3+fixes
- Added:
   + Allow getgrouplist() on glibc-2.2.6-alt0.10 as it contains 
     needed fix for CAN-2003-0689

* Mon Sep 01 2003 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt32
- Rebuild for ALT Linux Sisyphus

* Mon Sep 01 2003 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt31
- RC2 + fixes
- Added:
   + Return back Using Samba (2nd edition)
- Fixed:
   + CP850 and CP437 now provided by Samba itself on platforms
     which do not support iconv

* Fri Aug 22 2003 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt30
- Fixed:
   + charset issues in nmbd
   + default charset behaviour for Solaris and iconv
- Disabled:
   + temprorary not package Using Samba as it moved to separate CVS module

* Fri Aug 22 2003 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt29
- Attempt to fix mixed mode joining errors

* Wed Aug 20 2003 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt28
- Use new version scheme

* Wed Aug 20 2003 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt27
- 3.0RC1+post fixes

* Wed Aug 06 2003 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt26
- CVS SAMBA_3_0 up to 2003/08/06

* Tue Jul 29 2003 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt25
- Fixed:
   + user/group enumeration when RA == 0 (was broken since alt23) (jerry)
   + return code for quota flags change when we have no priviledges to do so (metze)

* Tue Jul 29 2003 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt24
- Refine dependencies between subpackages
- Fix NT quotas and integrate them into upstream

* Mon Jul 28 2003 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt23
- Updated:
   + Patch from Stephan Metzemacher for default_quota
   + Patch from Stephan Metzemacher for NT quota
   + CVS SAMBA_3_0 up to 2003/07/28
   + Re-added samba-3.0.release.tar.bz2 (as of beta3)

* Wed Jul 16 2003 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt22
- 3.0beta3+post fixes
- Build documentation by default from Docbook sources
- remove convert_smbpassword as outdated script
- Fixed:
  + smbpasswd false errors when /etc/samba/smbpasswd does not exist

* Tue Jul 15 2003 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt21
- Major re-arrangement of files between sub-packages, it makes
  more reasonable split of binaries according to their purpose.
  Also, a number of missing manpages were added.
- Spec file unification for ALT Linux and ApplianceWare versions.
- Defaults:
   + ALT Linux: build xml and mysql passdb, use well-commented smb.conf
   + AW: disable xml and mysql passdb, use specific smb.conf

* Wed Jul 09 2003 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt20
- Changed:
    + Make %name-pdb-xml dependant on --enable/--disable xml
    + Make %name-pdb-mysql dependant on --enable/--disable mysql
    + Default for both is 'enable'
    + PreRequires glibc-gconv-modules

* Tue Jul 08 2003 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt19
- Changed:
    + smb and winbind initscripts are using start-stop-daemon now
- Added:
    + reload-config command to smbcontrol. smbd, nmbd, and winbindd are aware of it.
    
* Tue Jul 08 2003 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt18
- Stick to 2003-07-06 spanshot as Jerry and Jeremy started to rewrite
  bits of Auth and Idmap now and SAMBA_3_0 is broken currently.
- Apply open-dev-inode patch

* Fri Jul 04 2003 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt17
- Apply Andrew Bartlett's LDAP fixes, to eliminate last bits of 
  idmap problems in beta2

* Fri Jul 04 2003 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt16
- Fix idmap_init ignoring 'idmap backend' option
- Back out Jeremy's fixes to strupper/strlower as they are incomplete 
  and broke the build.

* Wed Jul 02 2003 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt15
- 3.0beta2
- Updated:
   + release-cvs patch to include diff between SAMBA_3_0_RELEASE 
     and SAMBA_3_0 (only version string so far)

* Tue Jul 01 2003 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt14
- Prepare for beta2
- Apply metze's move of default quota to VFS module
- Enable 'inherit acls' and 'inherit permissions' by default

* Wed Jun 25 2003 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt12
- pre-beta2 (2003-06-25)

* Mon Jun 09 2003 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt11
- Samba 3.0 beta 1 + post fixes for client plaintext auth
- Updated:
   + system-winbind pam module to reflect base packages
- Removed:
   + NT quota patch -- integrated into upstream

* Wed May 14 2003 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt10
- 2003-05-14
- Fixed:
    + VFS API macros prefixes with SMB_ to avoid clashes with 
      system-specific VFS_ macros on some platforms (AIX)
    + Quota configuration now runs test cases during configure to
      gather detailed information about quota API divergence
- Added:
    + new idmap
    + new LDAP schema -- read examples/LDAP!

* Mon May 12 2003 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt9
- 2003-05-12
- Fixed:
    + Cascaded VFS to finally support per-module local data storage
      (metze, ab, jelmer)
    + NT quotas stuff (metze, ab)

* Fri Apr 25 2003 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt8
- Added:
    + Stephan Metzmacher's NT Quotas support (experimental)
    + post alpha23 (See ChangeLog.SAMBA_3_0)
    + support for winbindd privileged pipe for winbind group members
- Splitted:
    + pdb_xml to %name-pdb-xml
    + pdb_mysql to %name-pdb-mysql

* Wed Feb 05 2003 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt7
- Fixed:
    + gencache must try to reopen its database in read-only mode
      if read-write/creation failed in order to keep non-priviledged
      clients continue working.

* Tue Feb 04 2003 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt6
- alpha21 (SAMBA_3_0 as of 2003-02-04)
- control(8) support added for smbmount
- sendfile support enabled by default
- Add ntml_auth helper and smbgroupedit.8 man page

* Fri Aug 09 2002 Stanislav Ievlev <inger@altlinux.ru> 3.0-alt5.1
- fixed suid/sgid file permissions
- building is no SMP compatible

* Wed Aug 07 2002 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt5
- Update to alpha18+post CVS fixes (really tons of changes)
- Updated:
    + Cascaded VFS integrated to upstream (ab, idra, abartlet)
    + Jan Kara quotas support
- Fixed:
    + block.so to use asprintf instead of strcat
    + spec file synchronized with 2.2 branch, new subpackages added
      (client-devel[-static], client-cups, vfs)

* Fri May 17 2002 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt4
- Fixed:
    + paths for piddir, lockdir, and swat
- Slightly modified build procedure to deal with SMP builds

* Thu Apr 18 2002 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt3
- Fixed:
    + xinet.d restart should affect samba3-swat only

* Thu Apr 18 2002 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt2
- Fixed:
    + Wrong requires (samba-common instead of samba3-common)
    + lockdir should be specified directly now

* Mon Apr 15 2002 Alexander Bokovoy <ab@altlinux.ru> 3.0-alt1
- Merge ApplianceWare changes into ALT Linux
- Added
    + Cascaded VFS patch (me)
    + Smbfs unicode fixes ported from 2.2 (me)
- Changed:
    + smb.conf to follow 3.0 development

* Fri Apr 05 2002 Alexander Bokovoy <ab@optifacio.com> 3.0-16aw
- Fix libcap dependency

* Wed Apr 03 2002 Alexander Bokovoy <ab@optifacio.com> 3.0-15aw
- Fix dependencies for vfs devel package

* Tue Apr 02 2002 Alexander Bokovoy <ab@optifacio.com> 3.0-13aw
- Integrated latest spec changes from ALT Linux
- Prepared VFS devel package

* Fri Mar 29 2002 Alexander Bokovoy <ab@optifacio.com> 3.0-12aw
- Fixed:
    + nmbd shutdown bug (rewritten shutdown process)
    + AD paged controls bug

* Mon Mar 25 2002 Alexander Bokovoy <ab@optifacio.com> 3.0-11aw
- Bring back libnss_winbind.so build

* Mon Mar 25 2002 Alexander Bokovoy <ab@optifacio.com> 3.0-10aw
- Updated:
    + aw-smbstatus patch
    
* Mon Mar 25 2002 Alexander Bokovoy <ab@optifacio.com> 3.0-9aw
- Fixed:
    + bug with file truncate (#0001081)
    + initscript for nmbd

* Wed Mar 06 2002 Alexander Bokovoy <ab@optifacio.com> 3.0-8aw
- Fixed:
    + initscript for nmbd

* Mon Feb 18 2002 Alexander Bokovoy <ab@optifacio.com> 3.0-6aw
- Fixed:
    + net ads
    + signed/unsigned

* Fri Feb 15 2002 Alexander Bokovoy <ab@optifacio.com> 3.0-5aw
- Fixed:
    + Bug in 'net ads'

* Wed Feb 06 2002 Alexander Bokovoy <ab@optifacio.com> 3.0-4aw
- Uncommented smbpasswd

* Fri Feb 01 2002 Alexander Bokovoy <ab@optifacio.com> 3.0-3aw
- Samba CVS [20020201] update
- Fixed patch for smbstatus
- Reviewed set of utils

* Wed Jan 30 2002 Alexander Bokovoy <ab@optifacio.com> 3.0-2aw
- Use 3.0a14 as base

* Mon Jan 28 2002 Alexander Bokovoy <ab@optifacio.com> 3.0-1aw
- Move to 3.0

* Thu Jan 17 2002 Alexander Bokovoy <ab@optifacio.com> 2.2.2-alt11
- Fixed:
    + winbind default domain patch (me)
    + smb.conf (code pages information corrected, move to use own config)
    + popup message translation (Ihar Viarheichyk)
- Removed:
    + support for pam_smbpass, use winbind instead
- Changed:
    + changed attributes for smbmount/smbmnt to comply with relaity
    + winbindd moved to samba-common (server isn't required for its usage)
    + CUPS support splitted to samba-client-cups

* Fri Jan 04 2002 Alexander Bokovoy <ab@optifacio.com> 2.2.2-alt10
- Fixed:
    + bug in smbclient -L (jeremy)

* Fri Dec 21 2001 Alexander Bokovoy <ab@optifacio.com> 2.2.2-alt9
- Fixed:
    + pam_winbind's parse_domain_user updated to current version
    + system-auth-winbind updated to pam-config 1.1.1-alt1

* Thu Dec 20 2001 Alexander Bokovoy <ab@optifacio.com> 2.2.2-alt8
- Fixed:
    + winbind default domain patch (created new one)
    + Alpha_strcpy patch merged to upstream
- Updated:
    + system-auth-winbind to follow TCB integration
- Added:
    + make proto and winbindd_proto calls (they work again)

* Fri Nov 30 2001 Alexander Bokovoy <ab@optifacio.com> 2.2.2-alt7
- Build with new winbind code from HEAD

* Tue Nov 20 2001 Alexander Bokovoy <ab@optifacio.com> 2.2.2-alt6
- Fixed:
    + stop connection away problems (Tom Jansen)
    + error code handling in smbwrapper (new clierr code sync)
- Removed:
    + make proto call (prototypes for quotas get broken after it)

* Mon Nov 19 2001 Alexander Bokovoy <ab@optifacio.com> 2.2.2-alt5
- Fixed:
    + alpha_strcpy to handle non-latin1 characters (Ihar Viarheichyk)
    + back port of working Winbindd from HEAD (Jeremy Allison)
    + client-enc patch merged into upstream
    + pam_smbpass to remove conflicting namespaces with lib/util.c
- Updated:
    + Unified workgroup name patch
- Things left to do:
    + UTF-8 patch (Ihar Viarheichyk)

* Thu Nov 01 2001 Alexander Bokovoy <ab@optifacio.com> 2.2.2-alt4
- Fixed bug with non-ascii letters in smbclient and user and domain names
  More work is needed on user/domain area though. (Ihar Viarheichyk)
- Preparations for UTF-8/Unicode internal string processing patch by Ihar Viarheichyk
- Added recent ChangeLog for SAMBA_2_2 branch
- Version string changed to "ALT Linux/2.2.2" in order to comply with Tridge's call
  for easy identification of vendor-specific versions

* Sat Oct 20 2001 Dmitry V. Levin <ldv@alt-linux.org> 2.2.2-alt3
- Moved documentation to separate subpackage.
- Corrected documentation a bit, to fix dependencies.

* Thu Oct 18 2001 Alexander Bokovoy <ab@optifacio.com> 2.2.2-alt2
- rebuild against new glibc
- fix of spec cleanup for _shareddir.
- Fix Swat location for FHS conformance

* Mon Oct 15 2001 Alexander Bokovoy <ab@optifacio.com> 2.2.2-alt1
- 2.2.2
- minor spec clean up (Grigory Milev)

* Thu Oct 11 2001 Alexander Bokovoy <ab@optifacio.com> 2.2.1a-alt11
- Fixed:
+ Memory leaks in Winbindd (close to final fix)
+ SAM management
+ Most patches were successfully integrated into mainstream
- Last build of 2.2.2-pre, next one should be official 2.2.2
- Added:
+ System auth via winbind (fixed spelling errors in Mandrake's version)

* Thu Aug 30 2001 Alexander Bokovoy <ab@optifacio.com> 2.2.1a-alt10
- Fixed:
+ Winbindd talloc, new shiny challenge encryption protocols (tpot)
+ pam_smbpass and smb_passwd API changes (Steve Langasek and me, patch #516)
- Added:
+ preliminary support for ACLs

* Mon Aug 20 2001 Alexander Bokovoy <ab@optifacio.com> 2.2.1a-alt9
- Fixed:
+ Winbindd with some realoc-related problems
- Updated documentation (patch #30 has been merged into mainstream)

* Mon Aug 13 2001 Alexander Bokovoy <ab@optifacio.com> 2.2.1a-alt8
- Fixed:
+ Winbindd to properly set up default workgroup name
+ Winbindd to validate against current domain, not default one
- Added:
+ Winbind init script

* Mon Aug 13 2001 Alexander Bokovoy <ab@optifacio.com> 2.2.1a-alt7
- Fixed:
+ Symlinks /sbin/mount.smb and /sbin/mount.smbfs now point to /usr/bin/smbmount
+ SWAT documentation for winbindd has been fixed (samedit is outdated)

* Mon Aug 13 2001 Alexander Bokovoy <ab@optifacio.com> 2.2.1a-alt6
- Various fixes in /etc/samba/smb.conf
- Patch 21 is removed
- NSS patch for seamless domain integration enhanced. Users from default
  domain now are accepted without explicit DOMAIN exposure in the username.

* Wed Aug 08 2001 Alexander Bokovoy <ab@optifacio.com> 2.2.1a-alt5
- Symlink for libnss_winbind.so.2 added
- pam_smbpass.so and smbwrapper.so moved to /lib/security
- Help about pam_smbpass is added in README.pam_smbpass and into
  examples/pam_smbpass

* Wed Aug 08 2001 Alexander Bokovoy <ab@optifacio.com> 2.2.1a-alt4
- First build with Winbind support integrated
- See winbindd(8), smb.conf(5) for proper configuration
- Buildreq fixed for cups-devel (libcups-devel)
- smb start up script is fixed

* Tue Jul 31 2001 Stanislav Ievlev <inger@altlinux.ru> 2.2.1a-alt3
- Light spec cleanup.
- Returned right version of /etc/rc.d/init.d/smb

* Thu Jul 19 2001 AEN <aen@logic.ru> 2.2.1a-alt2
- fix permissions on /var/spool/samba
* Thu Jul 12 2001 AEN <aen@logic.ru> 2.2.1a-alt1
- 2.2.1a
- %post fixed

* Wed Jul 11 2001 AEN <aen@logic.ru> 2.2.1-alt7
- PreReq: libcups in samba-common
* Wed Jul 11 2001 AEN <aen@logic.ru> 2.2.1-alt6
- build oficial release
- sync with MDK

* Wed Jun 27 2001 AEN <aen@logic.ru> 2.2.1-alt5
- smb.init fixed -- thnx to  Sviatoslav Sviridov

* Sun Jun 24 2001 AEN <aen@logic.ru> 2.2.1-alt4
- new code with security fix
- %preun_service macros name fixed

* Thu Jun 14 2001 AEN <aen@logic.ru> 2.2.1-alt3
- cups problem  solved (patch from mdk)

* Wed May 30 2001 AEN <aen@logic.ru> 2.2.1-alt2
- new code from CVS
- configuration files moved to /etc/samba
- sync with MDK

* Mon May 21 2001 AEN <aen@logic.ru> 2.2.1-alt1
- new version
- alt patch adopted

* Wed Apr 25 2001 AEN <aen@logic.ru> 2.2.0-alt2
- inetd problem fixed
- sync with MDK

* Thu Apr 19 2001 AEN <aen@logic.ru> 2.0.8-alt2
- tmpdir patch

* Wed Apr 18 2001 AEN <aen@logic.ru>
- 2.0.8
- rh patches

* Wed Apr 18 2001 AEN <aen@logic.ru> 2.2.0-alt1
- new spec from samba tarball
- build for Sisyphus
- 1251 patch

* Wed Dec 06 2000 AEN <aen@logic.ru>
- 1251 patch
- build for RE

* Thu Nov 23 2000 Sylvestre Taburet <staburet@mandrakesoft.com> 2.0.7-20mdk
- removed dependencies on cups and cups-devel so one can install samba without using cups
- added /home/netlogon

* Mon Nov 20 2000 Till Kamppeter <till@mandrakesoft.com> 2.0.7-19mdk
- Changed default print command in /etc/smb.conf, so that the Windows
  driver of the printer has to be used on the client.
- Fixed bug in smbspool which prevented from printing from a
  Linux-Samba-CUPS client to a Windows server through the guest account.

* Mon Oct 16 2000 Till Kamppeter <till@mandrakesoft.com> 2.0.7-18mdk
- Moved "smbspool" (Samba client of CUPS) to the samba-client package

* Sat Oct 7 2000 Stefan van der Eijk <s.vandereijk@chello.nl> 2.0.7-17mdk
- Added RedHat's "quota" patch to samba-glibc21.patch.bz2, this fixes
  quota related compile problems on the alpha.

* Wed Oct 4 2000 Sylvestre Taburet <staburet@mandrakesoft.com> 2.0.7-16mdk
- Fixed 'guest ok = ok' flag in smb.conf

* Tue Oct 3 2000 Sylvestre Taburet <staburet@mandrakesoft.com> 2.0.7-15mdk
- Allowed guest account to print in smb.conf
- added swat icon in menu

* Tue Oct 3 2000 Sylvestre Taburet <staburet@mandrakesoft.com> 2.0.7-14mdk
- Removed rh ssl patch and --with-ssl flag: not appropriate for 7.2

* Tue Oct 3 2000 Sylvestre Taburet <staburet@mandrakesoft.com> 2.0.7-13mdk
- Changed fixinit patch.
- Changed smb.conf for better CUPS configuration.
- Thanks Fred for doing this ---vvv.

* Tue Oct  3 2000 Frederic Lepied <flepied@mandrakesoft.com> 2.0.7-12mdk
- menu entry for web configuration tool.
- merge with rh: xinetd + ssl + pam_stack.
- Added smbadduser rh-bugfix w/o relocation of config-files.

* Mon Oct  2 2000 Frederic Lepied <flepied@mandrakesoft.com> 2.0.7-11mdk
- added build requires on cups-devel and pam-devel.

* Mon Oct  2 2000 Till Kamppeter <till@mandrakesoft.com> 2.0.7-10mdk
- Fixed smb.conf entry for CUPS: "printcap name = lpstat", "lpstats" was
  wrong.

* Mon Sep 25 2000 Sylvestre Taburet <staburet@mandrakesoft.com> 2.0.7-9mdk
- Cosmetic changes to make rpmlint more happy

* Wed Sep 11 2000 Sylvestre Taburet <staburet@mandrakesoft.com> 2.0.7-8mdk
- added linkage to the using_samba book in swat

* Fri Sep 01 2000 Sylvestre Taburet <staburet@mandrakesoft.com> 2.0.7-7mdk
- Added CUPS support to smb.conf
- Added internationalization options to smb.conf [Global]

* Wed Aug 30 2000 Till Kamppeter <till@mandrakesoft.com> 2.0.7-6mdk
- Put "smbspool" to the files to install

* Wed Aug 30 2000 Sylvestre Taburet <staburet@mandrakesoft.com> 2.0.7-5mdk
- Did some cleaning in the patches

* Fri Jul 28 2000 Sylvestre Taburet <staburet@mandrakesoft.com> 2.0.7-4mdk
- relocated man pages from /usr/man to /usr/share/man for compatibility reasons

* Fri Jul 28 2000 Sylvestre Taburet <staburet@mandrakesoft.com> 2.0.7-3mdk
- added make_unicodemap and build of unicode_map.$i in the spec file

* Fri Jul 28 2000 Sylvestre Taburet <staburet@mandrakesoft.com> 2.0.7-2mdk
- renamed /etc/codepage/codepage.$i into /etc/codepage/unicode_map.$i to fix smbmount bug.

* Fri Jul 07 2000 Sylvestre Taburet <staburet@mandrakesoft.com> 2.0.7-1mdk
- 2.0.7

* Wed Apr 05 2000 Francis Galiegue <fg@mandrakesoft.com> 2.0.6-4mdk

- Titi sucks, does not put versions in changelog
- Fixed groups for -common and -client
- /usr/sbin/samba is no config file

* Thu Mar 23 2000 Thierry Vignaud <tvignaud@mandrakesoft.com>
- fix buggy post install script (pixel)

* Fri Mar 17 2000 Francis Galiegue <francis@mandrakesoft.com> 2.0.6-2mdk

- Changed group according to 7.1 specs
- Some spec file changes
- Let spec-helper do its job

* Thu Nov 25 1999 Chmouel Boudjnah <chmouel@mandrakesoft.com>
- 2.0.6.

* Tue Nov  2 1999 Chmouel Boudjnah <chmouel@mandrakesoft.com>
- Merge with rh changes.
- Split in 3 packages.

* Fri Aug 13 1999 Pablo Saratxaga <pablo@@mandrakesoft.com>
- corrected a bug with %post (the $1 parameter is "1" in case of
  a first install, not "0". That parameter is the number of packages
  of the same name that will exist after running all the steps if nothing
  is removed; so it is "1" after first isntall, "2" for a second install
  or an upgrade, and "0" for a removal)

* Wed Jul 28 1999 Pablo Saratxaga <pablo@@mandrakesoft.com>
- made smbmnt and smbumount suid root, and only executable by group 'smb'
  add to 'smb' group any user that should be allowed to mount/unmount
  SMB shared directories

* Fri Jul 23 1999 Chmouel Boudjnah <chmouel@mandrakesoft.com>
- 2.0.5a (bug security fix).

* Wed Jul 21 1999 Axalon Bloodstone <axalon@linux-mandrake.com>
- 2.0.5
- cs/da/de/fi/fr/it/tr descriptions/summaries

* Sun Jun 13 1999 Bernhard Rosenkrnzer <bero@mandrakesoft.com>
- 2.0.4b
- recompile on a system that works ;)

* Wed Apr 21 1999 Chmouel Boudjnah <chmouel@mandrakesoft.com>
- Mandrake adaptations.
- Bzip2 man-pages.

* Fri Mar 26 1999 Bill Nottingham <notting@redhat.com>
- add a mount.smb to make smb mounting a little easier.
- smb filesystems apparently do not work on alpha. Oops.

* Thu Mar 25 1999 Bill Nottingham <notting@redhat.com>
- always create codepages

* Tue Mar 23 1999 Bill Nottingham <notting@redhat.com>
- logrotate changes

* Sun Mar 21 1999 Cristian Gafton <gafton@redhat.com>
- auto rebuild in the new build environment (release 3)

* Fri Mar 19 1999 Preston Brown <pbrown@redhat.com>
- updated init script to use graceful restart (not stop/start)

* Tue Mar  9 1999 Bill Nottingham <notting@redhat.com>
- update to 2.0.3

* Thu Feb 18 1999 Bill Nottingham <notting@redhat.com>
- update to 2.0.2

* Mon Feb 15 1999 Bill Nottingham <notting@redhat.com>
- swat swat

* Tue Feb  9 1999 Bill Nottingham <notting@redhat.com>
- fix bash2 breakage in post script

* Fri Feb  5 1999 Bill Nottingham <notting@redhat.com>
- update to 2.0.0

* Mon Oct 12 1998 Cristian Gafton <gafton@redhat.com>
- make sure all binaries are stripped

* Thu Sep 17 1998 Jeff Johnson <jbj@redhat.com>
- update to 1.9.18p10.
- fix %triggerpostun.

* Tue Jul 07 1998 Erik Troan <ewt@redhat.com>
- updated postun triggerscript to check $0
- clear /etc/codepages from %preun instead of %postun

* Mon Jun 08 1998 Erik Troan <ewt@redhat.com>
- made the %postun script a tad less agressive; no reason to remove
  the logs or lock file (after all, if the lock file is still there,
  samba is still running)
- the %postun and %preun should only exectute if this is the final
  removal
- migrated %triggerpostun from Red Hat's samba package to work around
  packaging problems in some Red Hat samba releases

* Sun Apr 26 1998 John H Terpstra <jht@samba.anu.edu.au>
- minor tidy up in preparation for release of 1.9.18p5
- added findsmb utility from SGI package

* Wed Mar 18 1998 John H Terpstra <jht@samba.anu.edu.au>
- Updated version and codepage info.
- Release to test name resolve order

* Sat Jan 24 1998 John H Terpstra <jht@samba.anu.edu.au>
- Many optimisations (some suggested by Manoj Kasichainula <manojk@io.com>
- Use of chkconfig in place of individual symlinks to /etc/rc.d/init/smb
- Compounded make line
- Updated smb.init restart mechanism
- Use compound mkdir -p line instead of individual calls to mkdir
- Fixed smb.conf file path for log files
- Fixed smb.conf file path for incoming smb print spool directory
- Added a number of options to smb.conf file
- Added smbadduser command (missed from all previous RPMs) - Doooh!
- Added smbuser file and smb.conf file updates for username map



